#!/bin/sh
##
## Written for Debian on behalf of the Debian Science Team
## by Jerome Benoit <calculus@rezozer.net>, 2014-11-13.
##
INVOCATIONNAME=${0##*/}

case ${INVOCATIONNAME} in
	action.sh) VARIANT=ogl ;;
	action-*.sh)
		VARIANT=${INVOCATIONNAME%.sh}
		VARIANT=${VARIANT#action-}
		case ${VARIANT} in
			nox|ogl) ;;
			*) echo >&2 "ERROR: unknown variant \`${VARIANT}'"; exit 1 ;;
		esac
		;;
	clean.sh)
		rm -f *.tga
		exit 0
		;;
	*) echo >&2 "ERROR: unexpected script name \`${0}'"; exit 1 ;;
esac

TACHYON=/usr/bin/tachyon-$VARIANT

TACHYON_OPTS=
TACHYON_OPTS="-numthreads 3"

if [ ! -x $TACHYON ]; then
	echo >&2 "ERROR: cannot find executable \`$TACHYON'"
	echo >&2 "ERROR: You may want to install the Debian package \`tachyon-bin-$VARIANT'"
	exit 1
fi

lauch_cmd () {
	local cmd="$@"
	echo
	echo "=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+"
	echo "$cmd"
	echo "=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-"
	sh -c "$cmd"
	return 0
	}

listof_acfile=$(find . -type f -a -name '*.ac')
listof_datfile=$(find . -type f -a -name '*.dat')
listof_camfile=$(find . -type f -a -name '*.cam')

if true; then
for acfile in $listof_acfile; do
	outfile=${acfile%.ac}-$VARIANT.tga
	rm -f $outfile
	lauch_cmd "$TACHYON ${TACHYON_OPTS} -o $outfile -format TARGA $acfile"
done
fi

if true; then
for datfile in $listof_datfile; do
	outfile=${datfile%.dat}-$VARIANT.tga
	rm -f $outfile
	lauch_cmd "$TACHYON ${TACHYON_OPTS} -o $outfile -format TARGA $datfile"
done
fi

if true; then
for camfile in $listof_camfile; do
	datfile=${camfile%.cam}.dat
	if [ -r $datfile ]; then
		lauch_cmd "$TACHYON ${TACHYON_OPTS} -nosave -camfile $camfile $datfile"
	fi
done
fi

exit 0
## eos
